import QtQuick 2.0
import Sailfish.Silica 1.0

Page {
    SilicaListView {
        anchors.fill: parent
        spacing: Theme.paddingMedium
        model: contacts
        clip: true

        delegate: ListItem {
            id: listItem
            width: parent.width
            contentHeight: Theme.itemSizeMedium
            menu: ContextMenu {
                MenuItem {
                    text: "Update"
                    onClicked: {
                        listItem.updateContact();
                    }
                }

                MenuItem {
                    text: "Remove"
                    onClicked: {
                        contacts.remove(index)
                    }
                }
            }

            Label {
                id: nameLabel
                text: name + " " + surname
                color: listItem.highlighted ? Theme.highlightColor : Theme.primaryColor
            }
            Label {
                id: ageLabel
                anchors {
                    top: nameLabel.bottom
                }
                text: "Age: " + age
                color: listItem.highlighted ? Theme.highlightColor : Theme.primaryColor
            }

            function updateContact() {
                var dialog = pageStack.push("../dialogs/AddContactsDialog.qml",
                                            {contactName: name, contactSurname: surname,
                                            contactAge: age});
                dialog.accepted.connect(function() {
                    contacts.updateContact(index, dialog.contactName,
                                           dialog.contactSurname,
                                           dialog.contactAge);
                });
            }
        }

        PullDownMenu {
            MenuItem {
                text: "Add new contact"
                onClicked: {
                    var dialog = pageStack.push(Qt.resolvedUrl("../dialogs/AddContactsDialog.qml"))
                    dialog.accepted.connect(function() {
                        contacts.addContact(dialog.contactName,
                                            dialog.contactSurname,
                                            dialog.contactAge)
                    });
                }
            }
        }
    }
}
